@@ -1,3 +1,3 @@
 from .extension import Tailwind
 
-__all__ = [Tailwind]
+__all__ = ["Tailwind"]
